(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     27829,       1077]*)
(*NotebookOutlinePosition[     32531,       1250]*)
(*  CellTagsIndexPosition[     31593,       1209]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Calendar", "Section",
  CellTags->"0.1"],

Cell[TextData[{
  "The functions described in this section are utilities, but they are \
extremely important. There is no way to perform finance computations \
correctly without reliable calendar functions. The Finance Pack has to follow \
the conventions of the industry, therefore, it does not use the functions \
from the standard ",
  StyleBox["Calendar", "MB"],
  " package. "
}], "Text",
  CellTags->"0.2"],

Cell[TextData[{
  "This loads the subpackage ",
  StyleBox["Calendar", "MB"],
  ". We don't need to do this if we previously loaded ",
  StyleBox["Finance`.", "MB"]
}], "MathCaption",
  CellTags->"0.3"],

Cell["<< Finance`Calendar`", "Input",
  CellLabel->"In[1]:="],

Cell["Check what new functions are now available. ", "MathCaption",
  CellTags->"0.4"],

Cell[CellGroupData[{

Cell["?Finance`Calendar`*", "Input",
  CellLabel->"In[2]:="],

Cell["\<\
BaseYear      DayOfWeek     DaysBetween   ToCalendar    \
ToStringDate
DateQ         DayOfYear     LeapYearQ     ToJulian      YearsBetween
DayCountBasis\
\>", "Print",
  CellLabel->"From In[2]:="]
}, Open  ]],

Cell["Every function has an on\[Hyphen]line help message. ", "MathCaption",
  CellTags->"0.5"],

Cell[CellGroupData[{

Cell["?LeapYearQ", "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \("LeapYearQ[year] returns True if year is a leap year and False \
otherwise."\)], "Print"]
}, Open  ]],

Cell["Dates can be represented using any of three formats.  ", "Text",
  CellTags->"0.6"],

Cell[TextData[{
  "    \[FilledSmallSquare]  The date is represented by a list of three \
integers {",
  StyleBox["month", "TI"],
  ", ",
  StyleBox["day", "TI"],
  ", ",
  StyleBox["year", "TI"],
  "}. For example, {10, 9, 1987} denotes October 9, 1987. This is the \
\"calendar date\". "
}], "ItemizedText",
  CellTags->"0.6"],

Cell[TextData[{
  "    \[FilledSmallSquare]  The date is represented by the Julian date \
number. For example, the \"Julian date\" for October 9, 1987 is ",
  "2447078",
  ". This format is particularly useful for counting days. "
}], "ItemizedText"],

Cell[TextData[{
  "    \[FilledSmallSquare]  The date is represented by a six\[Hyphen]digit \
string \"",
  StyleBox["yymmdd", "TI"],
  "\". The first two digits represent the year, the middle two give the \
month, and the last two denote the day of the month. This is called the \
\"string date\". "
}], "ItemizedText"],

Cell[TextData[{
  "The string date representation is limited because it only covers one \
hundred years. For finance calculations, the first part of the twentieth \
century is usually unimportant compared to the first part of the twenty\
\[Hyphen]first century. Therefore, we count the years from a given base year. \
If the year part of the string date is less than the base year, we assume \
that this date is in the twenty\[Hyphen]first century. The default value of \
the base year is 1950. Therefore \"480508\" and \"820622\" represent May 8, \
2048, and June 22, 1982, respectively. You will soon see how to choose a \
different base year. Strictly speaking, \"",
  StyleBox["yymmdd",
    FontSlant->"Italic"],
  "\" represents the calendar date {",
  StyleBox["mm",
    FontSlant->"Italic"],
  ", ",
  StyleBox["dd",
    FontSlant->"Italic"],
  ", 19",
  StyleBox["yy",
    FontSlant->"Italic"],
  "} if ",
  StyleBox["yy",
    FontSlant->"Italic"],
  " > ",
  StyleBox["BaseYear ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`-\)]],
  " 1900 and {",
  StyleBox["mm",
    FontSlant->"Italic"],
  ", ",
  StyleBox["dd",
    FontSlant->"Italic"],
  ", 20",
  StyleBox["yy",
    FontSlant->"Italic"],
  "} if ",
  StyleBox["yy",
    FontSlant->"Italic"],
  " \[LessEqual] ",
  StyleBox["BaseYear",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`-\)]],
  " 1900."
}], "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              FormBox[
                RowBox[{"LeapYearQ", "[", 
                  StyleBox[
                    FormBox["year",
                      "TraditionalForm"],
                    FontFamily->"Times",
                    FontWeight->"Plain",
                    FontSlant->"Italic"], "]"}],
                "StandardForm"],
              "Input",
              FontWeight->"Plain"], 
            StyleBox[
              RowBox[{\(return\ True\ if\ \), 
                StyleBox["year",
                  FontSlant->"Italic"], \(\ 
                is\ a\ leap\ year\ and\ False\ otherwise\)}],
              "Text"]},
          {
            StyleBox[
              FormBox[
                RowBox[{"DateQ", "[", 
                  StyleBox[
                    FormBox["date",
                      "TraditionalForm"],
                    FontFamily->"Times",
                    FontWeight->"Plain",
                    FontSlant->"Italic"], "]"}],
                "StandardForm"],
              "Input",
              FontWeight->"Plain"], 
            StyleBox[
              RowBox[{\(return\ True\ if\ \), 
                StyleBox["date",
                  FontSlant->"Italic"], \(\ 
                represents\ a\ valid\ date\ and\ False\ otherwise\)}],
              "Text"]}
          }], DefinitionBox]]],

Cell["Calendar test functions. ", "Caption"],

Cell[TextData[{
  "While any nonnegative integer may be interpreted as a Julian date, it is \
possible that a six\[Hyphen]digit string or a list of three elements does not \
represent any date. For example, \"921330\" and {2, 29, 1993} are not dates. \
The function ",
  StyleBox["DateQ", "MB"],
  " checks whether a given string or list really represents a date. The \
function ",
  StyleBox["LeapQ", "MB"],
  " tests for leap years. "
}], "Text",
  CellTags->"0.8"],

Cell["1992 and 2000 are both leap years. ", "MathCaption",
  CellTags->"0.9"],

Cell[CellGroupData[{

Cell["LeapYearQ[1992]", "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["LeapYearQ[2000]", "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell["1993 and 2100 are not leap years. ", "MathCaption",
  CellTags->"0.10"],

Cell[CellGroupData[{

Cell["LeapYearQ[1993]", "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["LeapYearQ[2100]", "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[7]="]
}, Open  ]],

Cell["This is a valid date. ", "MathCaption",
  CellTags->"0.11"],

Cell[CellGroupData[{

Cell["DateQ[{1, 13, 1993}]", "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[8]="]
}, Open  ]],

Cell["\<\
No month has 32 days so {8, 32, 1995} is not a valid calendar date. \
\
\>", "MathCaption",
  CellTags->"0.12"],

Cell[CellGroupData[{

Cell["DateQ[{8, 32, 1995}]", "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell["\<\
1993 is not a leap year, therefore, February has only 28 days. \
\
\>", "MathCaption",
  CellTags->"0.13"],

Cell[CellGroupData[{

Cell["DateQ[{2, 29, 1993}]", "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell["\<\
The string \"991201\" represents a date, namely December 1, 1999. \
\
\>", "MathCaption",
  CellTags->"0.14"],

Cell[CellGroupData[{

Cell["DateQ[\"991201\"]", "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell["The string \"981301\" does not represent a valid date. ", "MathCaption",
  CellTags->"0.15"],

Cell[CellGroupData[{

Cell["DateQ[\"991301\"]", "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["ToJulian",
                "MR",
                FontFamily->"Courier"], 
              StyleBox["[",
                "MR",
                FontFamily->"Courier"], 
              StyleBox["date",
                FontSlant->"Italic"], 
              StyleBox["]",
                "MR",
                FontFamily->"Courier"]}], 
            StyleBox[
              RowBox[{\(convert\ \), 
                StyleBox["date",
                  FontSlant->"Italic"], \(\ to\ the\ Julian\ date\)}],
              "TraditionalForm"]},
          {
            RowBox[{
              StyleBox["ToCalendar",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["date",
                FontSlant->"Italic"], 
              StyleBox["]",
                "MR"]}], 
            StyleBox[
              RowBox[{\(convert\ \), 
                StyleBox["date",
                  FontSlant->"Italic"], \(\ to\ the\ calendar\ date\)}],
              "TraditionalForm"]},
          {
            RowBox[{
              StyleBox["ToStringDate",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["date",
                FontSlant->"Italic"], 
              StyleBox["]",
                "MR"]}], 
            StyleBox[
              RowBox[{\(convert\ \), 
                StyleBox["date",
                  FontSlant->"Italic"], \(\ to\ the\ string\ date\)}],
              "TraditionalForm"]}
          }], DefinitionBox]]],

Cell["Calendar conversion functions. ", "Caption"],

Cell[TextData[{
  "It is often necessary to convert from one date format to another. The ",
  StyleBox["Calendar", "MB"],
  " subpackage provides the ",
  StyleBox["ToJulian", "MB"],
  ", ",
  StyleBox["ToCalendar", "MB"],
  ", and ",
  StyleBox["ToStringDate", "MB"],
  " conversion functions. For string dates all three conversion functions \
work from January 1, ",
  StyleBox["BaseYear",
    FontSlant->"Italic"],
  " to December 31, (",
  StyleBox["BaseYear",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`+\)]],
  " 99), where the default value for ",
  StyleBox["BaseYear",
    FontSlant->"Italic"],
  " is 1950. "
}], "Text",
  CellTags->"0.17"],

Cell["This gives the Julian date for February 1, 1993. ", "MathCaption",
  CellTags->"0.18"],

Cell[CellGroupData[{

Cell["ToJulian[{2, 1, 1993}]", "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \(2449020\)], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell[TextData[{
  "The function ",
  StyleBox["ToCalendar", "MB"],
  " converts a Julian date to a calendar date. "
}], "MathCaption",
  CellTags->"0.19"],

Cell[CellGroupData[{

Cell["ToCalendar[%]", "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \({2, 1, 1993}\)], "Output",
  CellLabel->"Out[14]="]
}, Open  ]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(option\ name\),
              "TraditionalForm",
              FontSlant->"Italic"], 
            StyleBox[\(default\ value\),
              "TraditionalForm",
              FontSlant->"Italic"], " "},
          {
            StyleBox["BaseYear",
              "TraditionalForm"], 
            StyleBox["1950",
              "TraditionalForm"], 
            RowBox[{
              StyleBox["the",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["base",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["year",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["used",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["for",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["the",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["string",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["date",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["representation",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["of",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["a",
                FontSlant->"Plain"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["date",
                "TraditionalForm"]}]}
          },
        RowSpacings->1.5,
        ColumnSpacings->2,
        ColumnWidths->{0.2, 0.2, 0.6},
        ColumnAlignments->{Left, Center, Left}], NotebookDefault]], 
  "DefinitionBox",
  CellFrame->0.5,
  CellHorizontalScrolling->True,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  Background->RGBColor[1, 0.8, 0.6],
  GridBoxOptions->{RowLines->{True, False}}],

Cell[TextData[{
  "Option for ",
  StyleBox["ToCalendar", "Input"],
  " and ",
  StyleBox["ToJulian", "MR"],
  "."
}], "Caption"],

Cell[TextData[{
  "Converting from a string date depends on the base year, so the ",
  StyleBox["ToCalendar", "MB"],
  " and ",
  StyleBox["ToJulian", "MB"],
  " functions have the option ",
  StyleBox["BaseYear", "MB"],
  ". "
}], "Text",
  CellTags->"0.21"],

Cell[TextData[{
  "The string date \"510101\" represents January 1, 1951 since the default \
for ",
  StyleBox["BaseYear", "MB"],
  " is 1950. "
}], "MathCaption",
  CellTags->"0.22"],

Cell[CellGroupData[{

Cell["ToCalendar[\"510101\"]", "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \({1, 1, 1951}\)], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell["\<\
If 1951 is chosen as the base year, \"500101\" represents January \
1, 2050. \
\>", "MathCaption",
  CellTags->"0.23"],

Cell[CellGroupData[{

Cell["ToCalendar[\"500101\", BaseYear -> 1951]", "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    \({1, 1, 2050}\)], "Output",
  CellLabel->"Out[16]="]
}, Open  ]],

Cell["Here is the Julian date representation of June 22, 1982. ", 
  "MathCaption",
  CellTags->"0.24"],

Cell[CellGroupData[{

Cell["ToJulian[\"820622\"]", "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \(2445143\)], "Output",
  CellLabel->"Out[17]="]
}, Open  ]],

Cell["This converts a calendar date to a string date. ", "MathCaption",
  CellTags->"0.25"],

Cell[CellGroupData[{

Cell["ToStringDate[{10, 9, 1987}]", "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \("871009"\)], "Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell["\<\
Here is an example of conversion from a Julian date to a string \
date. \
\>", "MathCaption",
  CellTags->"0.26"],

Cell[CellGroupData[{

Cell["ToStringDate[2445143]", "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \("820622"\)], "Output",
  CellLabel->"Out[19]="]
}, Open  ]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["DaysBetween",
                "TraditionalForm"], 
              StyleBox["[",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox[\(date2, \ date1\),
                FontSlant->"Italic"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["]",
                "TraditionalForm"]}], 
            RowBox[{
              StyleBox["give",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["the",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["number",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["of",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["days",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["between",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["date1",
                FontSlant->"Italic"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["and",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["date2",
                "TraditionalForm",
                FontSlant->"Italic"]}]}
          }], TopBox]],
  GridBoxOptions->{ColumnWidths->{0.32, 0.6}}],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["YearsBetween",
                "TraditionalForm"], 
              StyleBox["[",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox[\(date2, \ date1\),
                FontSlant->"Italic"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["]",
                "TraditionalForm"]}], 
            RowBox[{
              RowBox[{
                StyleBox["give",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["the",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["number",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["of",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["years",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["between",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["date1",
                  FontSlant->"Italic"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["and",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["date2",
                  "TraditionalForm",
                  FontSlant->"Italic"]}], 
              StyleBox[",",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox[\(taking\ into\ account\ fractions\ of\ years\),
                "TraditionalForm"]}]}
          }], MiddleBox]],
  GridBoxOptions->{ColumnWidths->{0.32, 0.6}}],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["DayOfWeek",
                "TraditionalForm"], 
              StyleBox["[",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["date",
                FontSlant->"Italic"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["]",
                "TraditionalForm"]}], 
            StyleBox[\(return\ the\ day\ of\ the\ week\ as\ a\ string\),
              "TraditionalForm"]}
          }], MiddleBox]],
  GridBoxOptions->{ColumnWidths->{0.32, 0.6}}],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["DayOfYear",
                "TraditionalForm"], 
              StyleBox["[",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["date",
                FontSlant->"Italic"], 
              StyleBox["]",
                "TraditionalForm"]}], 
            StyleBox[\(return\ the\ day\ of\ the\ year\ as\ an\ integer\),
              "TraditionalForm"]}
          }], BottomBox]],
  GridBoxOptions->{ColumnWidths->{0.32, 0.6}}],

Cell["Calendar functions. ", "Caption"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(option\ name\),
              "TraditionalForm",
              FontSlant->"Italic"], 
            StyleBox[\(default\ value\),
              "TraditionalForm",
              FontSlant->"Italic"], " "},
          {
            StyleBox["DayCountBasis",
              "TraditionalForm"], 
            StyleBox[\(Actual/Actual\),
              "TraditionalForm"], 
            
            StyleBox[\(an\ option\ for\ DayBetween\ and\ YearsBetween, \ 
              which\ can\ be\ \(Actual/Actual\ \) 
                \(30/360 \(, \ \) Actual/360 \(, \ or\) 30/Actual\)\),
              "TraditionalForm"]}
          },
        RowSpacings->1.5,
        ColumnSpacings->2,
        ColumnWidths->{0.2, 0.2, 0.6},
        ColumnAlignments->{Left, Center, Left}], NotebookDefault]], 
  "DefinitionBox",
  CellFrame->0.5,
  CellHorizontalScrolling->True,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  Background->RGBColor[1, 0.8, 0.6],
  GridBoxOptions->{RowLines->{True, False}}],

Cell[TextData[{
  "Option for ",
  StyleBox["DaysBetween", "MR"],
  " and ",
  StyleBox["YearsBetween", "MR"],
  "."
}], "Caption"],

Cell[TextData[{
  "The functions ",
  StyleBox["DaysBetween", "MB"],
  " and ",
  StyleBox["YearsBetween", "MB"],
  " have the option ",
  StyleBox["DayCountBasis", "MB"],
  ". "
}], "MathCaption",
  CellTags->"0.29"],

Cell[CellGroupData[{

Cell["Options[DaysBetween]", "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \({DayCountBasis \[Rule] "Actual/Actual"}\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options[YearsBetween]", "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \({DayCountBasis \[Rule] "Actual/Actual"}\)], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell["\<\
This returns the number of days between January 13, 1992 and August \
13, 1995. \
\>", "MathCaption",
  CellTags->"0.31"],

Cell[CellGroupData[{

Cell["DaysBetween[{8, 31, 1995}, {1, 13, 1992}]", "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \(1326\)], "Output",
  CellLabel->"Out[22]="]
}, Open  ]],

Cell["\<\
Using the 30/360 day count basis we get a different number of days. \
\
\>", "MathCaption",
  CellTags->"0.32"],

Cell[CellGroupData[{

Cell["\<\
DaysBetween[{8, 13, 1995}, {1, 13, 1992},
   DayCountBasis -> \"30/360\"]\
\>", "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    \(1290\)], "Output",
  CellLabel->"Out[23]="]
}, Open  ]],

Cell[TextData[{
  "We can change the default value of ",
  StyleBox["DayCountBasis", "MB"],
  " globally. "
}], "MathCaption",
  CellTags->"0.33"],

Cell[CellGroupData[{

Cell["SetOptions[DaysBetween, DayCountBasis -> \"30/360\"]", "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    \({DayCountBasis \[Rule] "30/360"}\)], "Output",
  CellLabel->"Out[24]="]
}, Open  ]],

Cell[TextData[{
  "Now ",
  StyleBox["Mathematica", "TI"],
  " uses the \"30/360\" day count basis as the default. "
}], "MathCaption",
  CellTags->"0.34"],

Cell[CellGroupData[{

Cell["DaysBetween[{8, 13, 1995}, {1, 13, 1992}]", "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \(1290\)], "Output",
  CellLabel->"Out[25]="]
}, Open  ]],

Cell["\<\
We can still use the \"Actual/Actual\" day count basis, but we have \
to specify it explicitly. \
\>", "MathCaption",
  CellTags->"0.35"],

Cell[CellGroupData[{

Cell["\<\
DaysBetween[{8, 13, 1995}, {1, 13, 1992},
   DayCountBasis -> \"Actual/Actual\"]\
\>", "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \(1308\)], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell["We return to the original setting. ", "MathCaption",
  CellTags->"0.36"],

Cell[CellGroupData[{

Cell["\<\
SetOptions[DaysBetween,
   DayCountBasis -> \"Actual/Actual\"]\
\>", "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \({DayCountBasis \[Rule] "Actual/Actual"}\)], "Output",
  CellLabel->"Out[27]="]
}, Open  ]],

Cell["\<\
This gives the number of years between January 13, 1992 and August \
13, 1995. \
\>", "MathCaption",
  CellTags->"0.37"],

Cell[CellGroupData[{

Cell["YearsBetween[{8, 31, 1995}, {1, 13, 1992}]", "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \(484963\/133590\)], "Output",
  CellLabel->"Out[28]="]
}, Open  ]],

Cell["Here is a numerical approximation of the above result. ", "MathCaption",
  CellTags->"0.38"],

Cell[CellGroupData[{

Cell["N[%]", "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \(3.63023429897447424`\)], "Output",
  CellLabel->"Out[29]="]
}, Open  ]],

Cell["We compute the same interval in the 30/360 day count basis. ", 
  "MathCaption",
  CellTags->"0.39"],

Cell[CellGroupData[{

Cell["\<\
YearsBetween[{8, 31, 1995}, {1, 13, 1992},
   DayCountBasis -> \"30/360\"]\
\>", "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \(109\/30\)], "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell["Here is a numerical approximation of the above result. ", "MathCaption",
  CellTags->"0.40"],

Cell[CellGroupData[{

Cell["N[%]", "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \(3.6333333333333333`\)], "Output",
  CellLabel->"Out[31]="]
}, Open  ]],

Cell["In 1994, Independence Day will be on a Monday. ", "MathCaption",
  CellTags->"0.41"],

Cell[CellGroupData[{

Cell["DayOfWeek[{7, 4, 1994}]", "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    \("Monday"\)], "Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell["\<\
March 1 is day 61 of a leap year and day 60 of a non\[Hyphen]leap \
year. \
\>", "MathCaption",
  CellTags->"0.42"],

Cell[CellGroupData[{

Cell["DayOfYear[{3, 1, 1992}]", "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    \(61\)], "Output",
  CellLabel->"Out[33]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["DayOfYear[{3, 1, 1993}]", "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    \(60\)], "Output",
  CellLabel->"Out[34]="]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
CellGrouping->Manual,
WindowSize->{500, 350},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "ApplicationManual.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "0.1"->{
    Cell[1717, 49, 46, 1, 72, "Section",
      CellTags->"0.1"]},
  "0.2"->{
    Cell[1766, 52, 412, 9, 91, "Text",
      CellTags->"0.2"]},
  "0.3"->{
    Cell[2181, 63, 202, 6, 50, "MathCaption",
      CellTags->"0.3"]},
  "0.4"->{
    Cell[2450, 74, 86, 1, 31, "MathCaption",
      CellTags->"0.4"]},
  "0.5"->{
    Cell[2846, 91, 94, 1, 31, "MathCaption",
      CellTags->"0.5"]},
  "0.6"->{
    Cell[3143, 104, 89, 1, 33, "Text",
      CellTags->"0.6"],
    Cell[3235, 107, 328, 11, 38, "ItemizedText",
      CellTags->"0.6"]},
  "0.8"->{
    Cell[7019, 230, 467, 11, 91, "Text",
      CellTags->"0.8"]},
  "0.9"->{
    Cell[7489, 243, 77, 1, 31, "MathCaption",
      CellTags->"0.9"]},
  "0.10"->{
    Cell[7885, 266, 77, 1, 31, "MathCaption",
      CellTags->"0.10"]},
  "0.11"->{
    Cell[8283, 289, 65, 1, 31, "MathCaption",
      CellTags->"0.11"]},
  "0.12"->{
    Cell[8514, 302, 121, 4, 31, "MathCaption",
      CellTags->"0.12"]},
  "0.13"->{
    Cell[8802, 318, 116, 4, 31, "MathCaption",
      CellTags->"0.13"]},
  "0.14"->{
    Cell[9087, 334, 119, 4, 31, "MathCaption",
      CellTags->"0.14"]},
  "0.15"->{
    Cell[9371, 350, 98, 1, 31, "MathCaption",
      CellTags->"0.15"]},
  "0.17"->{
    Cell[11282, 417, 681, 24, 92, "Text",
      CellTags->"0.17"]},
  "0.18"->{
    Cell[11966, 443, 92, 1, 31, "MathCaption",
      CellTags->"0.18"]},
  "0.19"->{
    Cell[12231, 456, 154, 5, 32, "MathCaption",
      CellTags->"0.19"]},
  "0.21"->{
    Cell[15049, 556, 259, 9, 34, "Text",
      CellTags->"0.21"]},
  "0.22"->{
    Cell[15311, 567, 183, 6, 32, "MathCaption",
      CellTags->"0.22"]},
  "0.23"->{
    Cell[15672, 585, 128, 4, 31, "MathCaption",
      CellTags->"0.23"]},
  "0.24"->{
    Cell[15996, 601, 103, 2, 31, "MathCaption",
      CellTags->"0.24"]},
  "0.25"->{
    Cell[16270, 615, 91, 1, 31, "MathCaption",
      CellTags->"0.25"]},
  "0.26"->{
    Cell[16540, 628, 123, 4, 31, "MathCaption",
      CellTags->"0.26"]},
  "0.29"->{
    Cell[23180, 844, 217, 9, 32, "MathCaption",
      CellTags->"0.29"]},
  "0.31"->{
    Cell[23801, 875, 131, 4, 31, "MathCaption",
      CellTags->"0.31"]},
  "0.32"->{
    Cell[24121, 891, 121, 4, 31, "MathCaption",
      CellTags->"0.32"]},
  "0.33"->{
    Cell[24471, 910, 146, 5, 32, "MathCaption",
      CellTags->"0.33"]},
  "0.34"->{
    Cell[24845, 927, 155, 5, 31, "MathCaption",
      CellTags->"0.34"]},
  "0.35"->{
    Cell[25189, 944, 147, 4, 30, "MathCaption",
      CellTags->"0.35"]},
  "0.36"->{
    Cell[25572, 963, 78, 1, 30, "MathCaption",
      CellTags->"0.36"]},
  "0.37"->{
    Cell[25903, 979, 130, 4, 30, "MathCaption",
      CellTags->"0.37"]},
  "0.38"->{
    Cell[26233, 995, 98, 1, 30, "MathCaption",
      CellTags->"0.38"]},
  "0.39"->{
    Cell[26499, 1008, 106, 2, 30, "MathCaption",
      CellTags->"0.39"]},
  "0.40"->{
    Cell[26838, 1025, 98, 1, 30, "MathCaption",
      CellTags->"0.40"]},
  "0.41"->{
    Cell[27103, 1038, 90, 1, 30, "MathCaption",
      CellTags->"0.41"]},
  "0.42"->{
    Cell[27368, 1051, 125, 4, 30, "MathCaption",
      CellTags->"0.42"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"0.1", 28492, 1095},
  {"0.2", 28569, 1098},
  {"0.3", 28644, 1101},
  {"0.4", 28726, 1104},
  {"0.5", 28807, 1107},
  {"0.6", 28888, 1110},
  {"0.8", 29036, 1115},
  {"0.9", 29113, 1118},
  {"0.10", 29196, 1121},
  {"0.11", 29280, 1124},
  {"0.12", 29364, 1127},
  {"0.13", 29449, 1130},
  {"0.14", 29534, 1133},
  {"0.15", 29619, 1136},
  {"0.17", 29703, 1139},
  {"0.18", 29783, 1142},
  {"0.19", 29868, 1145},
  {"0.21", 29954, 1148},
  {"0.22", 30033, 1151},
  {"0.23", 30119, 1154},
  {"0.24", 30205, 1157},
  {"0.25", 30291, 1160},
  {"0.26", 30376, 1163},
  {"0.29", 30462, 1166},
  {"0.31", 30548, 1169},
  {"0.32", 30634, 1172},
  {"0.33", 30720, 1175},
  {"0.34", 30806, 1178},
  {"0.35", 30892, 1181},
  {"0.36", 30978, 1184},
  {"0.37", 31063, 1187},
  {"0.38", 31149, 1190},
  {"0.39", 31234, 1193},
  {"0.40", 31321, 1196},
  {"0.41", 31407, 1199},
  {"0.42", 31493, 1202}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 46, 1, 72, "Section",
  CellTags->"0.1"],
Cell[1766, 52, 412, 9, 91, "Text",
  CellTags->"0.2"],
Cell[2181, 63, 202, 6, 50, "MathCaption",
  CellTags->"0.3"],
Cell[2386, 71, 61, 1, 30, "Input"],
Cell[2450, 74, 86, 1, 31, "MathCaption",
  CellTags->"0.4"],

Cell[CellGroupData[{
Cell[2561, 79, 60, 1, 30, "Input"],
Cell[2624, 82, 207, 6, 93, "Print"]
}, Open  ]],
Cell[2846, 91, 94, 1, 31, "MathCaption",
  CellTags->"0.5"],

Cell[CellGroupData[{
Cell[2965, 96, 51, 1, 30, "Input"],
Cell[3019, 99, 109, 2, 44, "Print"]
}, Open  ]],
Cell[3143, 104, 89, 1, 33, "Text",
  CellTags->"0.6"],
Cell[3235, 107, 328, 11, 38, "ItemizedText",
  CellTags->"0.6"],
Cell[3566, 120, 250, 5, 38, "ItemizedText"],
Cell[3819, 127, 320, 7, 38, "ItemizedText"],
Cell[4142, 136, 1428, 48, 147, "Text"],
Cell[5573, 186, 1396, 40, 60, InheritFromParent],
Cell[6972, 228, 44, 0, 16, "Caption"],
Cell[7019, 230, 467, 11, 91, "Text",
  CellTags->"0.8"],
Cell[7489, 243, 77, 1, 31, "MathCaption",
  CellTags->"0.9"],

Cell[CellGroupData[{
Cell[7591, 248, 56, 1, 30, "Input"],
Cell[7650, 251, 62, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7749, 258, 56, 1, 30, "Input"],
Cell[7808, 261, 62, 2, 29, "Output"]
}, Open  ]],
Cell[7885, 266, 77, 1, 31, "MathCaption",
  CellTags->"0.10"],

Cell[CellGroupData[{
Cell[7987, 271, 56, 1, 30, "Input"],
Cell[8046, 274, 63, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8146, 281, 56, 1, 30, "Input"],
Cell[8205, 284, 63, 2, 29, "Output"]
}, Open  ]],
Cell[8283, 289, 65, 1, 31, "MathCaption",
  CellTags->"0.11"],

Cell[CellGroupData[{
Cell[8373, 294, 61, 1, 30, "Input"],
Cell[8437, 297, 62, 2, 29, "Output"]
}, Open  ]],
Cell[8514, 302, 121, 4, 31, "MathCaption",
  CellTags->"0.12"],

Cell[CellGroupData[{
Cell[8660, 310, 61, 1, 30, "Input"],
Cell[8724, 313, 63, 2, 29, "Output"]
}, Open  ]],
Cell[8802, 318, 116, 4, 31, "MathCaption",
  CellTags->"0.13"],

Cell[CellGroupData[{
Cell[8943, 326, 62, 1, 30, "Input"],
Cell[9008, 329, 64, 2, 29, "Output"]
}, Open  ]],
Cell[9087, 334, 119, 4, 31, "MathCaption",
  CellTags->"0.14"],

Cell[CellGroupData[{
Cell[9231, 342, 59, 1, 30, "Input"],
Cell[9293, 345, 63, 2, 29, "Output"]
}, Open  ]],
Cell[9371, 350, 98, 1, 31, "MathCaption",
  CellTags->"0.15"],

Cell[CellGroupData[{
Cell[9494, 355, 59, 1, 30, "Input"],
Cell[9556, 358, 64, 2, 29, "Output"]
}, Open  ]],
Cell[9635, 363, 1591, 50, 81, InheritFromParent],
Cell[11229, 415, 50, 0, 16, "Caption"],
Cell[11282, 417, 681, 24, 92, "Text",
  CellTags->"0.17"],
Cell[11966, 443, 92, 1, 31, "MathCaption",
  CellTags->"0.18"],

Cell[CellGroupData[{
Cell[12083, 448, 64, 1, 30, "Input"],
Cell[12150, 451, 66, 2, 29, "Output"]
}, Open  ]],
Cell[12231, 456, 154, 5, 32, "MathCaption",
  CellTags->"0.19"],

Cell[CellGroupData[{
Cell[12410, 465, 55, 1, 30, "Input"],
Cell[12468, 468, 71, 2, 29, "Output"]
}, Open  ]],
Cell[12554, 473, 2360, 73, 80, "DefinitionBox"],
Cell[14917, 548, 129, 6, 16, "Caption"],
Cell[15049, 556, 259, 9, 34, "Text",
  CellTags->"0.21"],
Cell[15311, 567, 183, 6, 32, "MathCaption",
  CellTags->"0.22"],

Cell[CellGroupData[{
Cell[15519, 577, 64, 1, 30, "Input"],
Cell[15586, 580, 71, 2, 29, "Output"]
}, Open  ]],
Cell[15672, 585, 128, 4, 31, "MathCaption",
  CellTags->"0.23"],

Cell[CellGroupData[{
Cell[15825, 593, 82, 1, 30, "Input"],
Cell[15910, 596, 71, 2, 29, "Output"]
}, Open  ]],
Cell[15996, 601, 103, 2, 31, "MathCaption",
  CellTags->"0.24"],

Cell[CellGroupData[{
Cell[16124, 607, 62, 1, 30, "Input"],
Cell[16189, 610, 66, 2, 29, "Output"]
}, Open  ]],
Cell[16270, 615, 91, 1, 31, "MathCaption",
  CellTags->"0.25"],

Cell[CellGroupData[{
Cell[16386, 620, 69, 1, 30, "Input"],
Cell[16458, 623, 67, 2, 29, "Output"]
}, Open  ]],
Cell[16540, 628, 123, 4, 31, "MathCaption",
  CellTags->"0.26"],

Cell[CellGroupData[{
Cell[16688, 636, 63, 1, 30, "Input"],
Cell[16754, 639, 67, 2, 29, "Output"]
}, Open  ]],
Cell[16836, 644, 1754, 53, 41, InheritFromParent],
Cell[18593, 699, 2093, 60, 42, InheritFromParent],
Cell[20689, 761, 654, 19, 26, InheritFromParent],
Cell[21346, 782, 591, 17, 26, InheritFromParent],
Cell[21940, 801, 39, 0, 16, "Caption"],
Cell[21982, 803, 1061, 31, 80, "DefinitionBox"],
Cell[23046, 836, 131, 6, 16, "Caption"],
Cell[23180, 844, 217, 9, 32, "MathCaption",
  CellTags->"0.29"],

Cell[CellGroupData[{
Cell[23422, 857, 62, 1, 30, "Input"],
Cell[23487, 860, 98, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23622, 867, 63, 1, 30, "Input"],
Cell[23688, 870, 98, 2, 29, "Output"]
}, Open  ]],
Cell[23801, 875, 131, 4, 31, "MathCaption",
  CellTags->"0.31"],

Cell[CellGroupData[{
Cell[23957, 883, 83, 1, 30, "Input"],
Cell[24043, 886, 63, 2, 29, "Output"]
}, Open  ]],
Cell[24121, 891, 121, 4, 31, "MathCaption",
  CellTags->"0.32"],

Cell[CellGroupData[{
Cell[24267, 899, 123, 4, 48, "Input"],
Cell[24393, 905, 63, 2, 29, "Output"]
}, Open  ]],
Cell[24471, 910, 146, 5, 32, "MathCaption",
  CellTags->"0.33"],

Cell[CellGroupData[{
Cell[24642, 919, 94, 1, 30, "Input"],
Cell[24739, 922, 91, 2, 29, "Output"]
}, Open  ]],
Cell[24845, 927, 155, 5, 31, "MathCaption",
  CellTags->"0.34"],

Cell[CellGroupData[{
Cell[25025, 936, 83, 1, 30, "Input"],
Cell[25111, 939, 63, 2, 27, "Output"]
}, Open  ]],
Cell[25189, 944, 147, 4, 30, "MathCaption",
  CellTags->"0.35"],

Cell[CellGroupData[{
Cell[25361, 952, 130, 4, 42, "Input"],
Cell[25494, 958, 63, 2, 27, "Output"]
}, Open  ]],
Cell[25572, 963, 78, 1, 30, "MathCaption",
  CellTags->"0.36"],

Cell[CellGroupData[{
Cell[25675, 968, 112, 4, 42, "Input"],
Cell[25790, 974, 98, 2, 27, "Output"]
}, Open  ]],
Cell[25903, 979, 130, 4, 30, "MathCaption",
  CellTags->"0.37"],

Cell[CellGroupData[{
Cell[26058, 987, 84, 1, 27, "Input"],
Cell[26145, 990, 73, 2, 43, "Output"]
}, Open  ]],
Cell[26233, 995, 98, 1, 30, "MathCaption",
  CellTags->"0.38"],

Cell[CellGroupData[{
Cell[26356, 1000, 46, 1, 27, "Input"],
Cell[26405, 1003, 79, 2, 27, "Output"]
}, Open  ]],
Cell[26499, 1008, 106, 2, 30, "MathCaption",
  CellTags->"0.39"],

Cell[CellGroupData[{
Cell[26630, 1014, 124, 4, 42, "Input"],
Cell[26757, 1020, 66, 2, 43, "Output"]
}, Open  ]],
Cell[26838, 1025, 98, 1, 30, "MathCaption",
  CellTags->"0.40"],

Cell[CellGroupData[{
Cell[26961, 1030, 46, 1, 27, "Input"],
Cell[27010, 1033, 78, 2, 27, "Output"]
}, Open  ]],
Cell[27103, 1038, 90, 1, 30, "MathCaption",
  CellTags->"0.41"],

Cell[CellGroupData[{
Cell[27218, 1043, 65, 1, 27, "Input"],
Cell[27286, 1046, 67, 2, 27, "Output"]
}, Open  ]],
Cell[27368, 1051, 125, 4, 30, "MathCaption",
  CellTags->"0.42"],

Cell[CellGroupData[{
Cell[27518, 1059, 65, 1, 27, "Input"],
Cell[27586, 1062, 61, 2, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27684, 1069, 65, 1, 27, "Input"],
Cell[27752, 1072, 61, 2, 27, "Output"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

